@@ -331,14 +331,14 @@ if __name__ == "__main__":
     class Test(object):
         def method(self, x, y=2):
             pass
-    print(getargtxt(Test.__init__))
-    print(getargtxt(Test.method))
-    print(isdefined('numpy.take', force_import=True))
-    print(isdefined('__import__'))
-    print(isdefined('.keys', force_import=True))
-    print(getobj('globals'))
-    print(getobj('globals().keys'))
-    print(getobj('+scipy.signal.'))
-    print(getobj('4.'))
-    print(getdoc(sorted))
-    print(getargtxt(sorted))
+    print(getargtxt(Test.__init__))  # spyder: test-skip
+    print(getargtxt(Test.method))  # spyder: test-skip
+    print(isdefined('numpy.take', force_import=True))  # spyder: test-skip
+    print(isdefined('__import__'))  # spyder: test-skip
+    print(isdefined('.keys', force_import=True))  # spyder: test-skip
+    print(getobj('globals'))  # spyder: test-skip
+    print(getobj('globals().keys'))  # spyder: test-skip
+    print(getobj('+scipy.signal.'))  # spyder: test-skip
+    print(getobj('4.'))  # spyder: test-skip
+    print(getdoc(sorted))  # spyder: test-skip
+    print(getargtxt(sorted))  # spyder: test-skip
